@@ -13,21 +13,21 @@ except ImportError,e:
 from shipping.fretefacil import FreteFacilShippingService
 from shipping.models import DeliverableProperty
 
-def fretefacil_shipping_handler(request, order_form):
+def fretefacil_shipping_handler(request, form, order=None):
     if request.session.get("free_shipping"): return
     settings.use_editable()
+    if form is not None: user_postcode = form.shipping_detail_postcode
+    else: user_postcode = settings.CLIENT_POSTCODE
     shippingservice = FreteFacilShippingService()
     cart = Cart.objects.from_request(request)
     delivery_value = 0.0
     if cart.has_items():
         for product in cart:
-            print DeliverableProperty.objects.values()
             properties = DeliverableProperty.objects.filter(sku=product.sku)
-            print properties
             if len(properties) > 0:
                 props = properties[0]
                 deliverable = shippingservice.create_deliverable(settings.STORE_POSTCODE,
-                                                                 props.postcode,
+                                                                 user_postcode,
                                                                  props.width,
                                                                  props.height,
                                                                  props.length,
